@@ -12,7 +12,7 @@ use Tags::HTML::Page::Begin;
 use Tags::HTML::Page::End;
 use Tags::Output::Raw;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub call {
 	my ($self, $env) = @_;
@@ -265,7 +265,7 @@ Default value is
 
 =head2 C<_css>
 
-Method to set css via C<$self->{'css'}> object.
+Method to set css via C<$self-E<gt>{'css'}> object.
 Argument is C<$self> only.
 
 =head2 C<_prepare_app>
@@ -280,7 +280,7 @@ output. Argument is C<$self> and C<$env>.
 
 =head2 C<_tags_middle>
 
-Method to set tags via C<$self->{'tags'}> object.
+Method to set tags via C<$self-E<gt>{'tags'}> object.
 Argument is C<$self> only.
 
 =head1 METHODS IMPLEMENTED
@@ -432,12 +432,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2021-2022
+© Michal Josef Špaček 2020-2022
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
